@@ -1,6 +1,9 @@
-print.summary.glmmPQL <- function(x, digits = max(3, getOption("digits") - 3),
+#' @importFrom stats naprint printCoefmat symnum
+#' @export
+print.summary.BTglmmPQL <- function(x, digits = max(3, getOption("digits") - 3),
                                    symbolic.cor = x$symbolic.cor,
-                                   signif.stars = getOption("show.signif.stars"),
+                                   signif.stars = 
+                                       getOption("show.signif.stars"),
                                    ...)  {
     cat("\nCall:\n", deparse(x$call), sep = "", fill = TRUE)
     p <- length(x$aliased)
